@@ -83,9 +83,9 @@ bool ConsoleModel::addOperation(const Analitza::Expression& e, const QString& in
 
         const auto result = res.toHtml();
         addMessage(QStringLiteral("<a title='%1' href='kalgebra:/query?id=copy&func=%2'><span class='exp'>%3</span></a><br />=<a title='kalgebra:%1' href='kalgebra:/query?id=copy&func=%4'><span class='result'>%5</span></a>")
-                        .arg(i18n("Paste to Input"), e.toString(), e.toHtml(), res.toString(), result));
+                        .arg(i18n("Paste to Input"), e.toString(), e.toHtml(), res.toString(), result), e, res);
     } else {
-        addMessage(i18n("<ul class='error'>Error: <b>%1</b><li>%2</li></ul>", input.toHtmlEscaped(), a.errors().join(QStringLiteral("</li>\n<li>"))));
+        addMessage(i18n("<ul class='error'>Error: <b>%1</b><li>%2</li></ul>", input.toHtmlEscaped(), a.errors().join(QStringLiteral("</li>\n<li>"))), {}, {});
     }
 
     return a.isCorrect();
@@ -107,9 +107,9 @@ bool ConsoleModel::loadScript(const QUrl& path)
     }
 
     if(correct)
-        addMessage(i18n("Imported: %1", path.toDisplayString()));
+        addMessage(i18n("Imported: %1", path.toDisplayString()), {}, {});
     else
-        addMessage(i18n("<ul class='error'>Error: Could not load %1. <br /> %2</ul>", path.toDisplayString(), a.errors().join(QStringLiteral("<br/>"))));
+        addMessage(i18n("<ul class='error'>Error: Could not load %1. <br /> %2</ul>", path.toDisplayString(), a.errors().join(QStringLiteral("<br/>"))), {}, {});
 
     return correct;
 }
@@ -143,11 +143,11 @@ void ConsoleModel::setVariables(const QSharedPointer<Analitza::Variables>& vars)
     a.setVariables(vars);
 }
 
-void ConsoleModel::addMessage(const QString& msg)
+void ConsoleModel::addMessage(const QString& msg, const Analitza::Expression& operation, const Analitza::Expression& result)
 {
     m_htmlLog += msg.toUtf8();
     Q_EMIT updateView();
-    Q_EMIT message(msg);
+    Q_EMIT message(msg, operation, result);
 }
 
 bool ConsoleModel::saveLog(const QUrl& savePath) const
